==> chaosmesh-model-6.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkDuplicateSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkDuplicateSpecFluentImpl<A extends NetworkDuplicateSpecFluent<A>> extends BaseFluent<A> implements NetworkDuplicateSpecFluent<A>{
  public NetworkDuplicateSpecFluentImpl() {
  }
  public NetworkDuplicateSpecFluentImpl(NetworkDuplicateSpec instance) {
    this.withCorrelation(instance.getCorrelation()); 
    this.withDevice(instance.getDevice()); 
    this.withEgressPort(instance.getEgressPort()); 
    this.withHostname(instance.getHostname()); 
    this.withIpAddress(instance.getIpAddress()); 
    this.withIpProtocol(instance.getIpProtocol()); 
    this.withPercent(instance.getPercent()); 
    this.withSourcePort(instance.getSourcePort()); 
  }
  private String correlation;
  private String device;
  private String egressPort;
  private String hostname;
  private String ipAddress;
  private String ipProtocol;
  private String percent;
  private String sourcePort;
  public String getCorrelation() {
    return this.correlation;
  }
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  public Boolean hasCorrelation() {
    return this.correlation != null;
  }
  public String getDevice() {
    return this.device;
  }
  public A withDevice(String device) {
    this.device=device; return (A) this;
  }
  public Boolean hasDevice() {
    return this.device != null;
  }
  public String getEgressPort() {
    return this.egressPort;
  }
  public A withEgressPort(String egressPort) {
    this.egressPort=egressPort; return (A) this;
  }
  public Boolean hasEgressPort() {
    return this.egressPort != null;
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getIpAddress() {
    return this.ipAddress;
  }
  public A withIpAddress(String ipAddress) {
    this.ipAddress=ipAddress; return (A) this;
  }
  public Boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  public String getIpProtocol() {
    return this.ipProtocol;
  }
  public A withIpProtocol(String ipProtocol) {
    this.ipProtocol=ipProtocol; return (A) this;
  }
  public Boolean hasIpProtocol() {
    return this.ipProtocol != null;
  }
  public String getPercent() {
    return this.percent;
  }
  public A withPercent(String percent) {
    this.percent=percent; return (A) this;
  }
  public Boolean hasPercent() {
    return this.percent != null;
  }
  public String getSourcePort() {
    return this.sourcePort;
  }
  public A withSourcePort(String sourcePort) {
    this.sourcePort=sourcePort; return (A) this;
  }
  public Boolean hasSourcePort() {
    return this.sourcePort != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkDuplicateSpecFluentImpl that = (NetworkDuplicateSpecFluentImpl) o;
    if (correlation != null ? !correlation.equals(that.correlation) :that.correlation != null) return false;
    if (device != null ? !device.equals(that.device) :that.device != null) return false;
    if (egressPort != null ? !egressPort.equals(that.egressPort) :that.egressPort != null) return false;
    if (hostname != null ? !hostname.equals(that.hostname) :that.hostname != null) return false;
    if (ipAddress != null ? !ipAddress.equals(that.ipAddress) :that.ipAddress != null) return false;
    if (ipProtocol != null ? !ipProtocol.equals(that.ipProtocol) :that.ipProtocol != null) return false;
    if (percent != null ? !percent.equals(that.percent) :that.percent != null) return false;
    if (sourcePort != null ? !sourcePort.equals(that.sourcePort) :that.sourcePort != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(correlation,  device,  egressPort,  hostname,  ipAddress,  ipProtocol,  percent,  sourcePort,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (egressPort != null) { sb.append("egressPort:"); sb.append(egressPort + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (ipProtocol != null) { sb.append("ipProtocol:"); sb.append(ipProtocol + ","); }
    if (percent != null) { sb.append("percent:"); sb.append(percent + ","); }
    if (sourcePort != null) { sb.append("sourcePort:"); sb.append(sourcePort); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkDuplicateSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkDuplicateSpecFluentImpl<A extends NetworkDuplicateSpecFluent<A>> extends BaseFluent<A> implements NetworkDuplicateSpecFluent<A>{
  public NetworkDuplicateSpecFluentImpl() {
  }
  public NetworkDuplicateSpecFluentImpl(NetworkDuplicateSpec instance) {
    if (instance != null) {
      this.withCorrelation(instance.getCorrelation());
      this.withDevice(instance.getDevice());
      this.withEgressPort(instance.getEgressPort());
      this.withHostname(instance.getHostname());
      this.withIpAddress(instance.getIpAddress());
      this.withIpProtocol(instance.getIpProtocol());
      this.withPercent(instance.getPercent());
      this.withSourcePort(instance.getSourcePort());
    }
  }
  private String correlation;
  private String device;
  private String egressPort;
  private String hostname;
  private String ipAddress;
  private String ipProtocol;
  private String percent;
  private String sourcePort;
  public String getCorrelation() {
    return this.correlation;
  }
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  public Boolean hasCorrelation() {
    return this.correlation != null;
  }
  public String getDevice() {
    return this.device;
  }
  public A withDevice(String device) {
    this.device=device; return (A) this;
  }
  public Boolean hasDevice() {
    return this.device != null;
  }
  public String getEgressPort() {
    return this.egressPort;
  }
  public A withEgressPort(String egressPort) {
    this.egressPort=egressPort; return (A) this;
  }
  public Boolean hasEgressPort() {
    return this.egressPort != null;
  }
  public String getHostname() {
    return this.hostname;
  }
  public A withHostname(String hostname) {
    this.hostname=hostname; return (A) this;
  }
  public Boolean hasHostname() {
    return this.hostname != null;
  }
  public String getIpAddress() {
    return this.ipAddress;
  }
  public A withIpAddress(String ipAddress) {
    this.ipAddress=ipAddress; return (A) this;
  }
  public Boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  public String getIpProtocol() {
    return this.ipProtocol;
  }
  public A withIpProtocol(String ipProtocol) {
    this.ipProtocol=ipProtocol; return (A) this;
  }
  public Boolean hasIpProtocol() {
    return this.ipProtocol != null;
  }
  public String getPercent() {
    return this.percent;
  }
  public A withPercent(String percent) {
    this.percent=percent; return (A) this;
  }
  public Boolean hasPercent() {
    return this.percent != null;
  }
  public String getSourcePort() {
    return this.sourcePort;
  }
  public A withSourcePort(String sourcePort) {
    this.sourcePort=sourcePort; return (A) this;
  }
  public Boolean hasSourcePort() {
    return this.sourcePort != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkDuplicateSpecFluentImpl that = (NetworkDuplicateSpecFluentImpl) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;

    if (!java.util.Objects.equals(device, that.device)) return false;

    if (!java.util.Objects.equals(egressPort, that.egressPort)) return false;

    if (!java.util.Objects.equals(hostname, that.hostname)) return false;

    if (!java.util.Objects.equals(ipAddress, that.ipAddress)) return false;

    if (!java.util.Objects.equals(ipProtocol, that.ipProtocol)) return false;

    if (!java.util.Objects.equals(percent, that.percent)) return false;

    if (!java.util.Objects.equals(sourcePort, that.sourcePort)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(correlation,  device,  egressPort,  hostname,  ipAddress,  ipProtocol,  percent,  sourcePort,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (egressPort != null) { sb.append("egressPort:"); sb.append(egressPort + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (ipProtocol != null) { sb.append("ipProtocol:"); sb.append(ipProtocol + ","); }
    if (percent != null) { sb.append("percent:"); sb.append(percent + ","); }
    if (sourcePort != null) { sb.append("sourcePort:"); sb.append(sourcePort); }
    sb.append("}");
    return sb.toString();
  }
  
}
